%define kmod_name lustre-client

%bcond_without lustre_tests

# in order to get kernel symset and/or kernel module dependencies into
# the RPM, in order to support weak-modules, the internal dependency gen-
# erator needs to be disabled
# this is done with (reduce the double % down to a single %):
#
# %%global _use_internal_dependency_generator 0
#
# on SLES10, /usr/lib/rpm/macros already sets this, so no harm in also
# defining it here (until Suse changes their mind)
#
# on RHEL5, however, we do need to explicitly disable the internal dep-
# endency generator and allow the external one be used
# but since RedHat's kABI is only a subset of the total kernel ABI, it
# doesn't include all of the symbols we (or OFED for that matter) need
# until RedHat includes all of the symbols we need in their symsets we
# cannot support weak-modules
# we did e-mail the maintainer of all of this stuff @redhat but got no
# response from them
#%%global _use_internal_dependency_generator 0

Summary: Lustre File System
Name: lustre-client
Version: 1.8.9
Release: 1.wc1.2
License: GPL
Group: Utilities/System
Source: lustre-%{version}.tar.gz
Patch1: b86cdba6.diff
URL: http://wiki.whamcloud.com/
BuildRoot: %{_tmppath}/lustre-%{version}-root
Obsoletes: lustre-lite, lustre-lite-utils, lustre-ldap nfs-utils-lustre
Provides: lustre-lite = %{version}, lustre-lite-utils = %{version}
Requires: kmod-%{kmod_name} = %{version}
# GSS requires this: BuildRequires: pkgconfig, libgssapi-devel >= 0.10
BuildRequires:  %kernel_module_package_buildreqs
%kernel_module_package -n %{kmod_name}

%description
Userspace tools and files for the Lustre file system.

%package source
Summary: Object-Based Disk storage driver source
Group: Development/Kernel

%description source
Lustre sources for further development

%package tests
Summary: Lustre testing framework
Group: Development/Kernel
Provides: %{name}-tests = %{version}
Requires: %{name} = %{version}, kmod-%{kmod_name} = %{version}

%description tests
This package contains a set of test binaries and scripts that are intended
to be used by the Lustre testing framework.

%prep
%setup -cqn lustre-%{version}
cd lustre-%{version}
%patch1 -p1 -b .getnamefix
cd ..
mv lustre-%{version} lustre
cd lustre
ln lustre/ChangeLog ../ChangeLog-lustre
ln lnet/ChangeLog ../ChangeLog-lnet
ln COPYING ../

%build
# if RPM_BUILD_NCPUS unset, set it
if [ -z "$RPM_BUILD_NCPUS" ] ; then
    RPM_BUILD_NCPUS=$(egrep -c "^cpu[0-9]+" /proc/stat 2>/dev/null || echo 0 :)
    if [ $RPM_BUILD_NCPUS -eq 0 ] ; then
        RPM_BUILD_NCPUS=1
    fi
    if [ $RPM_BUILD_NCPUS -gt 8 ] ; then
        RPM_BUILD_NCPUS=8
    fi
fi

rm -rf $RPM_BUILD_ROOT

# override %optflags so that the vendor's overzealous flags don't create
# build failures
%define optflags -g -O2 -Werror
CONFIGURE_ARGS="%{?configure_args} --with-release=%release"
%if %{with lustre_tests}
CONFIGURE_ARGS="$CONFIGURE_ARGS --enable-tests --enable-liblustre-tests"
%else
CONFIGURE_ARGS="$CONFIGURE_ARGS --disable-tests --disable-liblustre-tests"
%endif
for flavor in %flavors_to_build ; do
cp -ar lustre $flavor
pushd $flavor
%configure \
	--with-linux=%{kernel_source $flavor} \
	--with-linux-obj=%{kernel_source $flavor} \
	$CONFIGURE_ARGS
make -j $RPM_BUILD_NCPUS -s
popd
done

%install
for flavor in %flavors_to_build ; do
pushd $flavor
make install DESTDIR=$RPM_BUILD_ROOT
[ -e lustre/obdclass/llog_test.ko ] && cp lustre/obdclass/llog_test.ko $RPM_BUILD_ROOT/lib/modules/%{kverrel}${flavor%default}/updates/kernel/fs/lustre/
# our kmod build scripts expect extra dir, easier to stick with it
mv $RPM_BUILD_ROOT/lib/modules/%{kverrel}${flavor%default}/updates $RPM_BUILD_ROOT/lib/modules/%{kverrel}${flavor%default}/extra
mv $RPM_BUILD_ROOT/lib/modules/%{kverrel}${flavor%default}/extra/kernel $RPM_BUILD_ROOT/lib/modules/%{kverrel}${flavor%default}/extra/lustre-client
popd
done
# hack to avoid changing the libsysio code for "make install"
rm -f $RPM_BUILD_ROOT%{_libdir}/libsysio.a
chmod +x $RPM_BUILD_ROOT%{_libdir}/*.so* $RPM_BUILD_ROOT%{_libexecdir}/lustre/lc_common
rm -f $RPM_BUILD_ROOT%{_bindir}/config.sh

# Create the pristine source directory.
pushd default
mkdir -p $RPM_BUILD_ROOT/usr/src
rm -f lustre-source
ln -s $RPM_BUILD_ROOT/usr/src lustre-source
make distdir distdir=lustre-source/lustre-%{version}
chmod -R go-w lustre-source/lustre-%{version}
popd

%files
%defattr(-,root,root)
%doc COPYING ChangeLog-lustre ChangeLog-lnet
/sbin/mount.lustre
%{_bindir}/*
%{_sbindir}/*
%{_libdir}/liblustre.so
/usr/share/lustre
%{_mandir}/man?/*
%dir %{_libexecdir}/lustre
%{_libexecdir}/lustre/lc_common
%{_sysconfdir}/udev/rules.d/99-lustre.rules

%files source
%defattr(-,root,root)
%{_includedir}/lustre
%{_includedir}/linux/lustre*
%{_libdir}/libptlctl.a
%{_libdir}/liblustreapi.a
%{_libdir}/liblustre.a
/usr/src/lustre-%{version}

%if %{with lustre_tests}
%files tests
%{_libdir}/lustre/tests/*
%{_libdir}/lustre/liblustre/tests/*
%endif

%clean
rm -rf $RPM_BUILD_ROOT
